zms.zmsobject.ZMSObject

Package zms :: Module zmsobject :: Class ZMSObject |
[frames] | no frames]

# Class ZMSObject

                          zms.ZMSItem.ZMSItem --+
                                                |
          zms._accessmanager.AccessableObject --+
                                                |
              zms._versionmanager.VersionItem --+
                                                |
          zms.ZMSWorkflowItem.ZMSWorkflowItem --+
                                                |
                 zms._copysupport.CopySupport --+
                                                |
                    zms._cachemanager.ReqBuff --+
                                                |
             zms._deprecatedapi.DeprecatedAPI --+
                                                |
    zms._multilangmanager.MultiLanguageObject --+
                                                |
                   zms._exportable.Exportable --+
                                                |
                       zms._objattrs.ObjAttrs --+
                                                |
                 zms._objchildren.ObjChildren --+
                                                |
                     zms._objinputs.ObjInputs --+
                                                |
                       zms._objtypes.ObjTypes --+
                                                |
                 zms._pathhandler.PathHandler --+
                                                |
      zms._textformatmanager.TextFormatObject --+
                                                |
           zms._zreferableitem.ZReferableItem --+
                                                |
                                               ZMSObject

Version: 0.1

Instance Methods
__init__(self, id='', sort_id=0) ZMSObject.__init__ |
getPath(self, *args, **kwargs) |
isFeatureEnabled(self, feature='') |
f_css_defaults(self, REQUEST=None) ZMSObject.f_css_defaults |
zmi_css_defaults(self, REQUEST) ZMSObject.zmi_css_defaults |
get_uid(self, forced=False, implementation=None) |
set_uid(self, uid) |
get_oid(self) |
set_request_context(self, REQUEST, d) |
get_request_context(self, REQUEST, key, defaultValue=None) |
title(self) |
__proxy__(self) |
get_conf_blob(self, path, REQUEST, RESPONSE) ZMS.get_conf_blob |
MyFile |
FileFromData(self, data, filename='', content_type=None, mediadbStorable=False) Creates a new instance of a file from given data. |
ImageFromData(self, data, filename='', content_type=None, mediadbStorable=False) |
isMetaType(self, meta_type, REQUEST={}) |
isPageContainer(self) |
isPage(self) |
isPageElement(self) |
getTitle(self, REQUEST) |
getTitlealt(self, REQUEST) |
getType(self) |
is_resource(self) |
isResource(self, REQUEST) |
is_translated(self, lang) |
isTranslated(self, lang, REQUEST) |
isModifiedInParentLanguage(self, lang, REQUEST) |
is_visible(self) |
isVisible(self, REQUEST) |
get_size(self, REQUEST={}) |
getDCCoverage(self, REQUEST={}) |
getDCDescription(self, REQUEST) |
getSelf(self, meta_type=None) |
icon(self) |
zmi_icon(self, *args, **kwargs) ZMSObject.zmi_icon |
display_icon(self, REQUEST={}, meta_type=None, key='icon', zpt=True) ZMSObject.display_icon |
display_type(self, REQUEST={}, meta_type=None) |
breadcrumbs_obj_path(self, portalMaster=True) |
changeProperties(self, lang) |
manage_changeProperties(self, lang, REQUEST, RESPONSE=None) ZMSObject.manage_changeProperties |
getDeclId(self, REQUEST={}) |
aq_absolute_url(self, relative=0) |
getDeclUrl(self, REQUEST={}) |
getPageExt(self, REQUEST) |
getHref2Html(self, fct, pageext, REQUEST) |
getHref2IndexHtmlInContext(self, context, index_html=None, REQUEST=None, deep=1) |
getHref2IndexHtml(self, REQUEST, deep=1) |
getLevel(self) |
is_child_of(self, ob) |
isAncestor(self, ob) |
getParentByDepth(self, deep) |
getParentByLevel(self, level) |
getParentNode(self) |
getTreeNodes(self, REQUEST={}, meta_types=None) |
ajaxGetNodes(self, context=None, lang=None, xml_header=True, REQUEST=None) ZMSObject.ajaxGetNodes |
ajaxGetNode(self, context=None, lang=None, xml_header=True, meta_types=None, REQUEST=None) ZMSObject.ajaxGetNode |
ajaxGetParentNodes(self, lang, xml_header=True, meta_types=None, REQUEST=None) ZMSObject.ajaxGetParentNodes |
manage_ajaxGetChildNodes(self, lang, xml_header=True, meta_types=None, REQUEST=None) ZMSObject.manage_ajaxGetChildNodes |
ajaxGetChildNodes(self, lang, xml_header=True, meta_types=None, REQUEST=None) ZMSObject.ajaxGetChildNodes |
setSortId(self, sort_id) |
getSortId(self) |
manage_moveObjUp(self, lang, REQUEST, RESPONSE) ZMSObject.manage_moveObjUp |
manage_moveObjDown(self, lang, REQUEST, RESPONSE) ZMSObject.manage_moveObjDown |
manage_moveObjToPos(self, lang, pos, fmt=None, REQUEST=None, RESPONSE=None) ZMSObject.manage_moveObjToPos |
manage_executeMetacmd(self, id, lang, REQUEST, RESPONSE) MetacmdObject.manage_executeMetacmd |
ajaxGetBodyContent(self, REQUEST, forced=False) HTML presentation in body-content. |
getBodyContent(self, REQUEST, forced=False) |
renderShort(self, REQUEST, manage_main=False) |
printHtml(self, level, sectionizer, REQUEST, deep=True) |
xmlOnStartElement(self, sTagName, dTagAttrs, oParentNode) |
xmlOnEndElement(self) |
xmlOnCharacterData(self, sData, bInCData) |
xmlOnUnknownStartTag(self, sTagName, dTagAttrs) |
xmlOnUnknownEndTag(self, sTagName) |
xmlGetParent(self) |

Class Variables
| __doc__ = `"""ZMS product module."""`
| security = `ClassSecurityInfo()`
| QUOT = `chr(34)`
| MISC_ZMS = `'/++resource++zms_/img/'`
| FORM_LABEL_MANDATORY = `'<sup style="color:red">*</sup>'`
| spacer_gif = `'/++resource++zms_/img/spacer.gif'`
| zmi_navbar_brand = `PageTemplateFile('zpt/common/zmi_navbar_bra`...``
| zmi_breadcrumbs = `PageTemplateFile('zpt/common/zmi_breadcrumbs`...``
| zmi_breadcrumbs_obj_path = `PageTemplateFile('zpt/common/zmi_br`...``
| zmi_manage_tabs_message = `PageTemplateFile('zpt/common/zmi_man`...``
| zmi_html_head = `PageTemplateFile('zpt/common/zmi_html_head', g`...``
| zmi_body_header = `PageTemplateFile('zpt/common/zmi_body_header`...``
| zmi_body_footer = `PageTemplateFile('zpt/common/zmi_body_footer`...``
| zmi_html_foot = `PageTemplateFile('zpt/common/zmi_html_foot', g`...``
| zmi_pagination = `PageTemplateFile('zpt/common/zmi_pagination',`...``
| zmi_tabs = `PageTemplateFile('zpt/common/zmi_tabs', globals())`
| zmi_tabs_sub = `PageTemplateFile('zpt/common/zmi_tabs_sub', glo`...``
| zmi_ace_editor = `PageTemplateFile('zpt/common/zmi_ace_editor',`...``
| f_recordset_grid = `PageTemplateFile('zpt/object/f_recordset_gr`...``
| preview_html = `PageTemplateFile('zpt/object/preview', globals())`
| preview_top_html = `PageTemplateFile('zpt/object/preview_top', `...``
| f_api_html = `PageTemplateFile('zpt/object/f_api', globals())`
| f_api_top_html = `PageTemplateFile('zpt/object/f_api_top', glob`...``
| obj_input_fields = `PageTemplateFile('zpt/ZMSObject/input_field`...``
| obj_input_elements = `PageTemplateFile('zpt/ZMSObject/input_ele`...``

Method Details

### FileFromData(self, data, filename='', content_type=None, mediadbStorable=False) |
Creates a new instance of a file from given data. Parameters: `data` (`string`) - File-data (binary) `filename` (`string`) - Filename Returns: MyFile New instance of file.

Class Variable Details

  ### zmi_navbar_brand Value:
      PageTemplateFile('zpt/common/zmi_navbar_brand', globals())

  ### zmi_breadcrumbs Value:
      PageTemplateFile('zpt/common/zmi_breadcrumbs', globals())

  ### zmi_breadcrumbs_obj_path Value:
      PageTemplateFile('zpt/common/zmi_breadcrumbs_obj_path', globals())

  ### zmi_manage_tabs_message Value:
      PageTemplateFile('zpt/common/zmi_manage_tabs_message', globals())

  ### zmi_html_head Value:
      PageTemplateFile('zpt/common/zmi_html_head', globals())

  ### zmi_body_header Value:
      PageTemplateFile('zpt/common/zmi_body_header', globals())

  ### zmi_body_footer Value:
      PageTemplateFile('zpt/common/zmi_body_footer', globals())

  ### zmi_html_foot Value:
      PageTemplateFile('zpt/common/zmi_html_foot', globals())

  ### zmi_pagination Value:
      PageTemplateFile('zpt/common/zmi_pagination', globals())

  ### zmi_tabs_sub Value:
      PageTemplateFile('zpt/common/zmi_tabs_sub', globals())

  ### zmi_ace_editor Value:
      PageTemplateFile('zpt/common/zmi_ace_editor', globals())

  ### f_recordset_grid Value:
      PageTemplateFile('zpt/object/f_recordset_grid', globals())

  ### preview_top_html Value:
      PageTemplateFile('zpt/object/preview_top', globals())

  ### f_api_top_html Value:
      PageTemplateFile('zpt/object/f_api_top', globals())

  ### obj_input_fields Value:
      PageTemplateFile('zpt/ZMSObject/input_fields', globals())

  ### obj_input_elements Value:
      PageTemplateFile('zpt/ZMSObject/input_elements', globals())